@@ -29,7 +29,7 @@ describe('promise support', () => {
     it('provides fse.promises API', () => {
       const desc = Object.getOwnPropertyDescriptor(fse, 'promises')
       assert.ok(desc)
-      assert.equal(typeof desc.get, 'function')
+      assert.strictEqual(typeof desc.get, 'function')
     })
   }
 })
