@@ -1,6 +1,6 @@
 'use strict'
 
-const fs = require(process.cwd())
+const fs = require('../../')
 const os = require('os')
 const path = require('path')
 const assert = require('assert')
@@ -136,7 +136,7 @@ describe('+ copySync() / file', () => {
       describe('> when destination file does NOT exist', () => {
         describe('> when overwrite is true', () => {
           it('should copy the file and not throw an error', () => {
-            fs.copySync(src, dest, {overwrite: true})
+            fs.copySync(src, dest, { overwrite: true })
             const destData = fs.readFileSync(dest, 'utf8')
             assert.strictEqual(srcData, destData)
           })
@@ -144,7 +144,7 @@ describe('+ copySync() / file', () => {
 
         describe('> when overwrite is false', () => {
           it('should copy the file and not throw an error', () => {
-            fs.copySync(src, dest, {overwrite: false})
+            fs.copySync(src, dest, { overwrite: false })
             const destData = fs.readFileSync(dest, 'utf8')
             assert.strictEqual(srcData, destData)
           })
@@ -161,7 +161,7 @@ describe('+ copySync() / file', () => {
 
         describe('> when overwrite is true', () => {
           it('should copy the file and not throw an error', () => {
-            fs.copySync(src, dest, {overwrite: true})
+            fs.copySync(src, dest, { overwrite: true })
             destData = fs.readFileSync(dest, 'utf8')
             assert.strictEqual(srcData, destData)
           })
@@ -169,14 +169,14 @@ describe('+ copySync() / file', () => {
 
         describe('> when overwrite is false', () => {
           it('should not throw an error', () => {
-            fs.copySync(src, dest, {overwrite: false})
+            fs.copySync(src, dest, { overwrite: false })
 
             // copy never happened
             const destDataNew = fs.readFileSync(dest, 'utf8')
             assert.strictEqual(destData, destDataNew)
           })
           it('should throw an error when errorOnExist is true', () => {
-            assert.throws(() => fs.copySync(src, dest, {overwrite: false, errorOnExist: true}))
+            assert.throws(() => fs.copySync(src, dest, { overwrite: false, errorOnExist: true }))
 
             // copy never happened
             const destDataNew = fs.readFileSync(dest, 'utf8')
@@ -188,7 +188,7 @@ describe('+ copySync() / file', () => {
           it('should copy the file and not throw an error', () => {
             try {
               fs.chmodSync(dest, parseInt('444', 8))
-              fs.copySync(src, dest, {overwrite: true})
+              fs.copySync(src, dest, { overwrite: true })
               destData = fs.readFileSync(dest, 'utf8')
               assert.strictEqual(srcData, destData)
             } finally {
@@ -212,7 +212,7 @@ describe('+ copySync() / file', () => {
       })
 
       it('is an alias for overwrite', () => {
-        fs.copySync(src, dest, {clobber: false})
+        fs.copySync(src, dest, { clobber: false })
 
         // copy never happened
         const destDataNew = fs.readFileSync(dest, 'utf8')
