@@ -38,7 +38,7 @@ describe('fs-extra', () => {
 
       fse.ensureFileSync(src)
       fse.ensureFileSync(dest)
-      fse.copy(src, dest, {overwrite: false, errorOnExist: true}, err => {
+      fse.copy(src, dest, { overwrite: false, errorOnExist: true }, err => {
         assert(err)
         done()
       })
@@ -50,7 +50,7 @@ describe('fs-extra', () => {
 
       fse.ensureFileSync(src)
       fse.ensureFileSync(dest)
-      fse.copy(src, dest, {overwrite: false, errorOnExist: true}, err => {
+      fse.copy(src, dest, { overwrite: false, errorOnExist: true }, err => {
         assert(err)
         done()
       })
@@ -144,7 +144,9 @@ describe('fs-extra', () => {
         const srcTarget = path.join(TEST_DIR, 'destination')
         fse.mkdirSync(src)
         fse.mkdirSync(srcTarget)
-        fse.symlinkSync(srcTarget, path.join(src, 'symlink'))
+        // symlink type is only used for Windows and the default is 'file'.
+        // https://nodejs.org/api/fs.html#fs_fs_symlink_target_path_type_callback
+        fse.symlinkSync(srcTarget, path.join(src, 'symlink'), 'dir')
 
         fse.copy(src, dest, err => {
           assert.ifError(err)
@@ -340,11 +342,12 @@ describe('fs-extra', () => {
 
         const dest = path.join(TEST_DIR, 'dest')
 
-        fse.copySync(src, dest, filter)
-
-        assert(!fs.existsSync(path.join(dest, IGNORE)), 'directory was not ignored')
-        assert(!fs.existsSync(path.join(dest, IGNORE, 'file')), 'file was not ignored')
-        done()
+        fse.copy(src, dest, filter, err => {
+          assert.ifError(err)
+          assert(!fs.existsSync(path.join(dest, IGNORE)), 'directory was not ignored')
+          assert(!fs.existsSync(path.join(dest, IGNORE, 'file')), 'file was not ignored')
+          done()
+        })
       })
 
       it('should apply filter when it is applied only to dest', done => {
