@@ -1,11 +1,12 @@
 'use strict'
 
-const fs = require('graceful-fs')
+// TODO: enable this once graceful-fs supports bigint option.
+// const fs = require('graceful-fs')
+const fs = require('fs')
 const os = require('os')
 const fse = require(process.cwd())
 const path = require('path')
 const assert = require('assert')
-const rimraf = require('rimraf')
 
 /* global afterEach, beforeEach, describe, it */
 
@@ -19,16 +20,13 @@ function createSyncErrFn (errCode) {
 }
 
 const originalRenameSync = fs.renameSync
-const originalLinkSync = fs.linkSync
 
 function setUpMockFs (errCode) {
   fs.renameSync = createSyncErrFn(errCode)
-  fs.linkSync = createSyncErrFn(errCode)
 }
 
 function tearDownMockFs () {
   fs.renameSync = originalRenameSync
-  fs.linkSync = originalLinkSync
 }
 
 describe('moveSync()', () => {
@@ -36,35 +34,39 @@ describe('moveSync()', () => {
 
   beforeEach(() => {
     TEST_DIR = path.join(os.tmpdir(), 'fs-extra', 'move-sync')
-
     fse.emptyDirSync(TEST_DIR)
 
-    // Create fixtures:
-    fs.writeFileSync(path.join(TEST_DIR, 'a-file'), 'sonic the hedgehog\n')
-    fs.mkdirSync(path.join(TEST_DIR, 'a-folder'))
-    fs.writeFileSync(path.join(TEST_DIR, 'a-folder/another-file'), 'tails\n')
-    fs.mkdirSync(path.join(TEST_DIR, 'a-folder/another-folder'))
-    fs.writeFileSync(path.join(TEST_DIR, 'a-folder/another-folder/file3'), 'knuckles\n')
+    // Create fixtures
+    fse.outputFileSync(path.join(TEST_DIR, 'a-file'), 'sonic the hedgehog\n')
+    fse.outputFileSync(path.join(TEST_DIR, 'a-folder/another-file'), 'tails\n')
+    fse.outputFileSync(path.join(TEST_DIR, 'a-folder/another-folder/file3'), 'knuckles\n')
   })
 
-  afterEach(done => rimraf(TEST_DIR, done))
+  afterEach(() => fse.removeSync(TEST_DIR))
 
   it('should not move if src and dest are the same', () => {
     const src = `${TEST_DIR}/a-file`
     const dest = `${TEST_DIR}/a-file`
 
-    fse.moveSync(src, dest)
+    let errThrown = false
+    try {
+      fse.moveSync(src, dest)
+    } catch (err) {
+      assert.strictEqual(err.message, 'Source and destination must not be the same.')
+      errThrown = true
+    } finally {
+      assert(errThrown)
+    }
 
     // assert src not affected
     const contents = fs.readFileSync(src, 'utf8')
     const expected = /^sonic the hedgehog\r?\n$/
-    assert.ok(contents.match(expected), `${contents} match ${expected}`)
+    assert(contents.match(expected))
   })
 
   it('should error if src and dest are the same and src does not exist', () => {
     const src = `${TEST_DIR}/non-existent`
     const dest = src
-
     assert.throws(() => fse.moveSync(src, dest))
   })
 
@@ -76,7 +78,7 @@ describe('moveSync()', () => {
 
     const contents = fs.readFileSync(dest, 'utf8')
     const expected = /^sonic the hedgehog\r?\n$/
-    assert.ok(contents.match(expected), `${contents} match ${expected}`)
+    assert(contents.match(expected))
   })
 
   it('should not overwrite the destination by default', () => {
@@ -89,7 +91,7 @@ describe('moveSync()', () => {
     try {
       fse.moveSync(src, dest)
     } catch (err) {
-      assert.ok(err && err.code === 'EEXIST', 'throw EEXIST')
+      assert.strictEqual(err.message, 'dest already exists.')
     }
   })
 
@@ -101,9 +103,9 @@ describe('moveSync()', () => {
     assert(fs.existsSync(dest))
 
     try {
-      fse.moveSync(src, dest, {overwrite: false})
+      fse.moveSync(src, dest, { overwrite: false })
     } catch (err) {
-      assert.ok(err && err.code === 'EEXIST', 'throw EEXIST')
+      assert.strictEqual(err.message, 'dest already exists.')
     }
   })
 
@@ -114,14 +116,14 @@ describe('moveSync()', () => {
     // verify file exists already
     assert(fs.existsSync(dest))
 
-    fse.moveSync(src, dest, {overwrite: true})
+    fse.moveSync(src, dest, { overwrite: true })
 
     const contents = fs.readFileSync(dest, 'utf8')
     const expected = /^sonic the hedgehog\r?\n$/
     assert.ok(contents.match(expected), `${contents} match ${expected}`)
   })
 
-  it('should overwrite the destination directory if overwrite = true', done => {
+  it('should overwrite the destination directory if overwrite = true', () => {
     // Create src
     const src = path.join(TEST_DIR, 'src')
     fse.ensureDirSync(src)
@@ -135,7 +137,7 @@ describe('moveSync()', () => {
     assert(pathsBefore.indexOf('another-file') >= 0)
     assert(pathsBefore.indexOf('another-folder') >= 0)
 
-    fse.moveSync(src, dest, {overwrite: true})
+    fse.moveSync(src, dest, { overwrite: true })
 
     // verify dest does not have old stuff
     const pathsAfter = fs.readdirSync(dest)
@@ -145,7 +147,6 @@ describe('moveSync()', () => {
     // verify dest has new stuff
     assert(pathsAfter.indexOf('some-file') >= 0)
     assert(pathsAfter.indexOf('some-folder') >= 0)
-    done()
   })
 
   it('should create directory structure by default', () => {
@@ -159,7 +160,7 @@ describe('moveSync()', () => {
 
     const contents = fs.readFileSync(dest, 'utf8')
     const expected = /^sonic the hedgehog\r?\n$/
-    assert.ok(contents.match(expected), `${contents} match ${expected}`)
+    assert(contents.match(expected))
   })
 
   it('should work across devices', () => {
@@ -172,7 +173,7 @@ describe('moveSync()', () => {
 
     const contents = fs.readFileSync(dest, 'utf8')
     const expected = /^sonic the hedgehog\r?\n$/
-    assert.ok(contents.match(expected), `${contents} match ${expected}`)
+    assert(contents.match(expected))
     tearDownMockFs()
   })
 
@@ -187,36 +188,21 @@ describe('moveSync()', () => {
 
     const contents = fs.readFileSync(dest + '/another-file', 'utf8')
     const expected = /^tails\r?\n$/
-    assert.ok(contents.match(expected), `${contents} match ${expected}`)
-  })
-
-  it('should move folders across devices with EISDIR error', () => {
-    const src = `${TEST_DIR}/a-folder`
-    const dest = `${TEST_DIR}/a-folder-dest`
-
-    setUpMockFs('EISDIR')
-
-    fse.moveSync(src, dest)
-
-    const contents = fs.readFileSync(dest + '/another-folder/file3', 'utf8')
-    const expected = /^knuckles\r?\n$/
-    assert.ok(contents.match(expected), `${contents} match ${expected}`)
-    tearDownMockFs()
+    assert(contents.match(expected))
   })
 
   it('should overwrite folders across devices', () => {
     const src = `${TEST_DIR}/a-folder`
     const dest = `${TEST_DIR}/a-folder-dest`
-
     fs.mkdirSync(dest)
 
     setUpMockFs('EXDEV')
 
-    fse.moveSync(src, dest, {overwrite: true})
+    fse.moveSync(src, dest, { overwrite: true })
 
     const contents = fs.readFileSync(dest + '/another-folder/file3', 'utf8')
     const expected = /^knuckles\r?\n$/
-    assert.ok(contents.match(expected), `${contents} match ${expected}`)
+    assert(contents.match(expected))
     tearDownMockFs()
   })
 
@@ -230,35 +216,7 @@ describe('moveSync()', () => {
 
     const contents = fs.readFileSync(dest + '/another-folder/file3', 'utf8')
     const expected = /^knuckles\r?\n$/
-    assert.ok(contents.match(expected), `${contents} match ${expected}`)
-    tearDownMockFs()
-  })
-
-  it('should move folders across devices with EPERM error', () => {
-    const src = `${TEST_DIR}/a-folder`
-    const dest = `${TEST_DIR}/a-folder-dest`
-
-    setUpMockFs('EPERM')
-
-    fse.moveSync(src, dest)
-
-    const contents = fs.readFileSync(dest + '/another-folder/file3', 'utf8')
-    const expected = /^knuckles\r?\n$/
-    assert.ok(contents.match(expected), `${contents} match ${expected}`)
-    tearDownMockFs()
-  })
-
-  it('should move folders across devices with ENOTSUP error', () => {
-    const src = `${TEST_DIR}/a-folder`
-    const dest = `${TEST_DIR}/a-folder-dest`
-
-    setUpMockFs('ENOTSUP')
-
-    fse.moveSync(src, dest)
-
-    const contents = fs.readFileSync(dest + '/another-folder/file3', 'utf8')
-    const expected = /^knuckles\r?\n$/
-    assert.ok(contents.match(expected), `${contents} match ${expected}`)
+    assert(contents.match(expected))
     tearDownMockFs()
   })
 
@@ -270,11 +228,11 @@ describe('moveSync()', () => {
       // verify file exists already
       assert(fs.existsSync(dest))
 
-      fse.moveSync(src, dest, {clobber: true})
+      fse.moveSync(src, dest, { clobber: true })
 
       const contents = fs.readFileSync(dest, 'utf8')
       const expected = /^sonic the hedgehog\r?\n$/
-      assert.ok(contents.match(expected), `${contents} match ${expected}`)
+      assert(contents.match(expected))
     })
   })
 
@@ -306,7 +264,7 @@ describe('moveSync()', () => {
 
       const contents = fs.readFileSync(dest, 'utf8')
       const expected = /^sonic the hedgehog\r?\n$/
-      assert.ok(contents.match(expected), `${contents} match ${expected}`)
+      assert(contents.match(expected))
     })
   })
 
@@ -324,7 +282,7 @@ describe('moveSync()', () => {
     try {
       fs.writeFileSync(path.join(differentDevice, 'file'), 'hi')
     } catch (err) {
-      console.log("Can't write to device. Skipping moveSync test.")
+      console.log(`Can't write to device. Skipping moveSync test.`)
       __skipTests = true
     }
 
@@ -335,12 +293,8 @@ describe('moveSync()', () => {
         const src = '/mnt/some/weird/dir-really-weird'
         const dest = path.join(TEST_DIR, 'device-weird')
 
-        if (!fs.existsSync(src)) {
-          fse.mkdirpSync(src)
-        }
-
+        if (!fs.existsSync(src)) fse.mkdirpSync(src)
         assert(!fs.existsSync(dest))
-
         assert(fs.lstatSync(src).isDirectory())
 
         fse.moveSync(src, dest)
