@@ -2,7 +2,7 @@
 
 const fs = require('graceful-fs')
 const os = require('os')
-const fse = require(process.cwd())
+const fse = require('../../')
 const path = require('path')
 const assert = require('assert')
 
@@ -58,7 +58,7 @@ describe('+ move()', () => {
       // verify file exists already
       assert(fs.existsSync(dest))
 
-      fse.move(src, dest, {overwrite: true}, err => {
+      fse.move(src, dest, { overwrite: true }, err => {
         assert.ifError(err)
         fs.readFile(dest, 'utf8', (err, contents) => {
           const expected = /^sonic the hedgehog\r?\n$/
@@ -83,7 +83,7 @@ describe('+ move()', () => {
       assert(paths.indexOf('another-file') >= 0)
       assert(paths.indexOf('another-folder') >= 0)
 
-      fse.move(src, dest, {overwrite: true}, err => {
+      fse.move(src, dest, { overwrite: true }, err => {
         assert.ifError(err)
 
         // verify dest does not have old stuff
@@ -107,7 +107,7 @@ describe('+ move()', () => {
 
       setUpMockFs('EXDEV')
 
-      fse.move(src, dest, {overwrite: true}, err => {
+      fse.move(src, dest, { overwrite: true }, err => {
         assert.ifError(err)
         assert.strictEqual(fs.rename.callCount, 1)
 
@@ -143,7 +143,7 @@ describe('+ move()', () => {
       const dest = src
 
       fse.move(src, dest, err => {
-        assert.ifError(err)
+        assert.strictEqual(err.message, 'Source and destination must not be the same.')
         done()
       })
     })
@@ -163,7 +163,7 @@ describe('+ move()', () => {
       const dest = src
 
       fse.move(src, dest, err => {
-        assert.ifError(err)
+        assert.strictEqual(err.message, 'Source and destination must not be the same.')
         done()
       })
     })
@@ -188,7 +188,7 @@ describe('+ move()', () => {
       // verify file exists already
       assert(fs.existsSync(dest))
 
-      fse.move(src, dest, {overwrite: false}, err => {
+      fse.move(src, dest, { overwrite: false }, err => {
         assert.strictEqual(err.message, 'dest already exists.')
         done()
       })
@@ -279,7 +279,7 @@ describe('+ move()', () => {
       // verify file exists already
       assert(fs.existsSync(dest))
 
-      fse.move(src, dest, {clobber: true}, err => {
+      fse.move(src, dest, { clobber: true }, err => {
         assert.ifError(err)
         fs.readFile(dest, 'utf8', (err, contents) => {
           const expected = /^sonic the hedgehog\r?\n$/
